==> bee-ui-0.0.35.tgz: package/src/Select/index.js <==
import React, {
  PropTypes,
} from 'react';

import {
  ScrollView, Text, TouchableWithoutFeedback, View,
} from 'react-native';

import { isEqual, noop } from '../helper';

const propTypes = {
  children: PropTypes.node,
  multiple: PropTypes.bool,
  onChange: PropTypes.func,
  style: View.propTypes.style,
  value: PropTypes.any,
};
const defaultProps = {
  children: null,
  multiple: false,
  onChange: noop,
  style: null,
  value: null,
};

function Select({
  children, multiple, onChange, style, value,
}) {
  let children$ = children;

  // 兼容单个选项
  if (!Array.isArray(children$)) {
    children$ = children$ ? [children$] : [];
  }

  const values = [];
  const selected = [];
  const onSelect = (index) => {
    // 未定义回调
    if (onChange === undefined) return;

    // 单选
    if (!multiple) {
      onChange(values[index], index);
      return;
    }

    // 切换状态
    if (index in selected) {
      delete selected[index];
    } else {
      selected[index] = values[index];
    }

    // 执行回调
    onChange(selected.filter(option => option !== undefined), Object.keys(selected));
  };
  const isSelected = ({ props }, index) => {
    // 判断 selected
    let isTrue = value === undefined && props.selected; // eslint-disable-line

    // 判断 value
    if (multiple) {
      isTrue = isTrue || value.findIndex(_value => isEqual(_value, props.value)) !== -1;
    } else {
      if (selected.length > 1) return false;
      isTrue = isTrue || isEqual(value, props.value);
    }

    // 处理选中
    if (isTrue) {
      selected[index] = props.value;
      return true;
    }

    return false;
  };

  // 界面渲染
  return (
    <ScrollView style={style}>
      {children.map((item, index) => {
        let item$ = item;
        // 未设置 value 则取 children
        if (item$.type === Text && item$.props.value === undefined) {
          item$ = <Text {...item$.props} value={item$.props.children} />;
        }

        // 填充 values 相应键值
        values[index] = item$.props.value;

        // 是否选中
        const itemSelected = isSelected(item$, index);

        // Text 兼容
        if (item$.type === Text) {
          item$ = (
            <View style={{ flexDirection: 'row', justifyContent: 'space-between', alignItems: 'center' }}>
              <Text {...item$.props} style={[{ backgroundColor: 'transparent' }, item$.props.style]} />
              {itemSelected ? <Text>-</Text> : null}
            </View>
          );
        }

        // 渲染单条
        return (
          <TouchableWithoutFeedback onPress={() => onSelect(index)}>
            <View>
              <item$.type {...item$.props} selected={itemSelected} />
            </View>
          </TouchableWithoutFeedback>
        );
      })}
    </ScrollView>
  );
}

Select.propTypes = propTypes;
Select.defaultProps = defaultProps;

export default Select;

==> bee-ui-0.0.40.tgz: package/src/Select/index.js <==
import React, {
  PropTypes,
} from 'react';

import {
  Text, TouchableWithoutFeedback, View,
} from 'react-native';

import { isEqual, noop } from '../helper';

const propTypes = {
  children: PropTypes.node,
  multiple: PropTypes.bool,
  onChange: PropTypes.func,
  style: View.propTypes.style,
  value: PropTypes.any,
};
const defaultProps = {
  children: null,
  multiple: false,
  onChange: noop,
  style: null,
  value: null,
};

function Select({
  children, multiple, onChange, style, value,
}) {
  let children$ = children;

  // 兼容单个选项
  if (!Array.isArray(children$)) {
    children$ = children$ ? [children$] : [];
  }

  const values = [];
  const selected = [];
  const onSelect = (index) => {
    // 未定义回调
    if (onChange === undefined) return;

    // 单选
    if (!multiple) {
      onChange(values[index], index);
      return;
    }

    // 切换状态
    if (index in selected) {
      delete selected[index];
    } else {
      selected[index] = values[index];
    }

    // 执行回调
    onChange(selected.filter(option => option !== undefined), Object.keys(selected));
  };
  const isSelected = ({ props }, index) => {
    // 判断 selected
    let isTrue = value === undefined && props.selected; // eslint-disable-line

    // 判断 value
    if (multiple) {
      isTrue = isTrue || value.findIndex(_value => isEqual(_value, props.value)) !== -1;
    } else {
      if (selected.length > 1) return false;
      isTrue = isTrue || isEqual(value, props.value);
    }

    // 处理选中
    if (isTrue) {
      selected[index] = props.value;
      return true;
    }

    return false;
  };

  // 界面渲染
  return (
    <View style={style}>
      {children.map((item, index) => {
        const key = index;
        let item$ = item;
        // 未设置 value 则取 children
        if (item$.type === Text && item$.props.value === undefined) {
          item$ = <Text {...item$.props} value={item$.props.children} />;
        }

        // 填充 values 相应键值
        values[index] = item$.props.value;

        // 是否选中
        const itemSelected = isSelected(item$, index);

        // Text 兼容
        if (item$.type === Text) {
          item$ = (
            <View style={{ flexDirection: 'row', justifyContent: 'space-between', alignItems: 'center' }}>
              <Text {...item$.props} style={[{ backgroundColor: 'transparent' }, item$.props.style]} />
              {itemSelected ? <Text>-</Text> : null}
            </View>
          );
        }

        // 渲染单条
        return (
          <TouchableWithoutFeedback onPress={() => onSelect(index)} key={key}>
            <View>
              <item$.type {...item$.props} selected={itemSelected} />
            </View>
          </TouchableWithoutFeedback>
        );
      })}
    </View>
  );
}

Select.propTypes = propTypes;
Select.defaultProps = defaultProps;

export default Select;
